@@ -17,6 +17,11 @@
  **
  ****************************************************************************/
 #include "chgl.h"
+#if defined (Q_WS_MAC)
+#include <glu.h>
+#else
+#include <GL/glu.h>
+#endif
 #include <QtGui>
 #include <QtOpenGL>
 
@@ -78,10 +83,15 @@ void glRotateL( const double dang, const double x, const double y, const double
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-chGL::chGL(QWidget *parent) : QGLWidget(parent) {                                                        ///////////////
+#if defined (Q_WS_MAC)
+chGL::chGL(QWidget *parent) : QGLWidget(QGLFormat(QGL::StencilBuffer | QGL::AlphaChannel|QGL::DoubleBuffer|QGL::DepthBuffer|QGL::DirectRendering),parent) {                                                        ///////////////
+#else
+chGL::chGL(QWidget *parent) : QGLWidget(QGLFormat(QGL::StencilBuffer | QGL::AlphaChannel|QGL::DoubleBuffer|QGL::DepthBuffer|QGL::DirectRendering|QGL::StereoBuffers),parent) {                                                        ///////////////
+#endif
   //printf("chGL::chGL\n");
   pause=true;
   murx=0;
+  xrdist=-206.2;
   envirange=3.2;
   enviNoQ= new QAction("Exclude Q-peaks from environment listing", this);
   enviButt= new QToolButton(this);
@@ -140,6 +150,13 @@ chGL::chGL(QWidget *parent) : QGLWidget(parent) {
   grabGesture(Qt::PinchGesture);
   grabGesture(Qt::SwipeGesture);
 #endif
+  /*
+  QGLFormat fmt=QGLFormat::defaultFormat() ;
+  //fmt.setOption(QGL::StereoBuffers);
+  fmt.setOption(QGL::DirectRendering|QGL::StereoBuffers);
+  //fmt.setOption(QGL::);
+  setFormat(fmt);
+  */
   //                                                                                                     ///////////////
 }                                                                                                        ///////////////
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -712,6 +729,13 @@ void chGL::contextMenuEvent(QContextMenuEvent *event){
     if (ssgr){
       a=menu->addAction(QString("Move selected atoms to selected sites"),
 		      parent(),SLOT(moveSymmMateSel()));
+      //////// 28.03.12
+      if (mol->showatoms.at(idx).part<0){
+	a=menu->addAction(QString("Copy %1 here").arg(mol->showatoms.at(idx).Label.section("_",0,0)),
+			parent(),SLOT(copySymmMate()));
+	a->setData(idx);
+      }
+      //////// -
     }else{
       if (!mol->selectedatoms.isEmpty()){
 	a=menu->addAction(QIcon(":icons/killselected.png"),QString("Delete selected atoms"),
@@ -723,7 +747,7 @@ void chGL::contextMenuEvent(QContextMenuEvent *event){
 			parent(),SLOT(moveSymmMate()));
 	a->setData(idx);
 	if (mol->showatoms.at(idx).part<0){
-	  a=menu->addAction(QString("Insert a copy of %1 here").arg(mol->showatoms.at(idx).Label.section("_",0,0)),
+	  a=menu->addAction(QString("Copy %1 here").arg(mol->showatoms.at(idx).Label.section("_",0,0)),
 			  parent(),SLOT(copySymmMate()));
 	  a->setData(idx);
 	}
@@ -1075,6 +1099,7 @@ void chGL::initLists(){
     }
   }
   bas=glGenLists(10);
+  glPolygonMode(GL_FRONT_AND_BACK,GL_FILL);
   mol->tubes=0;
   mol->dratom=0;
   glLoadMatrixd(MM);
@@ -1331,6 +1356,18 @@ void chGL::anaglyphRedCyan(){
   updateGL();
 }
 
+void chGL::hardwareStereo(){
+    if (format().stereo()){
+     stereo_mode=5;
+     minus=-1;
+     updateGL();
+   }
+  else {
+    qDebug()<<"no stereo sorry!";
+    emit no_hw_st();
+  }
+}
+
 void chGL::nostereo(){
   stereo_mode=0;
   updateGL();
@@ -1455,6 +1492,7 @@ void chGL::paintGL(){
   // printf("%d ___%d %d %d\n",stereo_mode,ww,wh,mibas);
   glGetIntegerv(GL_VIEWPORT, vp);
   if (!stereo_mode){
+    glDrawBuffer(GL_BACK);
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
     gluPerspective( viewAngle, (double)ww/wh, 5.0, 8000.0 );
@@ -1490,6 +1528,7 @@ void chGL::paintGL(){
   }
   }else 
     if (stereo_mode==1){// stereo zalman
+    glDrawBuffer(GL_BACK);
       GLint viewport[4];
       glGetIntegerv(GL_VIEWPORT,viewport);
 
@@ -1640,6 +1679,7 @@ void chGL::paintGL(){
       }
     }else  
       if ((stereo_mode>1)&&(stereo_mode<4)) { //stereo_side by side
+    glDrawBuffer(GL_BACK);
 	if (xray_vision){
 	  glPushMatrix();
 	  glViewport(0, 0, ww/2, wh);        
@@ -1739,6 +1779,7 @@ void chGL::paintGL(){
 	}
       }
       else  if (stereo_mode==4){//anaglyph red cyan
+	glDrawBuffer(GL_BACK);
 	if (xray_vision){
 	  glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
 	  glColorMask(GL_TRUE, GL_FALSE, GL_FALSE, GL_TRUE);
@@ -1868,13 +1909,106 @@ void chGL::paintGL(){
 	  glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
 	}	 
 
-      }
+      }else  if (stereo_mode==5){//hardware stereo ???
+	//todo  is this working??
+	//x-ray view 
+	if (xray_vision){
+	  glPushMatrix();//2
+	  glViewport(0, 0, ww, wh);        
+	  glMatrixMode(GL_PROJECTION);
+	  glLoadIdentity();
+	  gluPerspective( viewAngle, (double)ww/wh, 5.0, 8000.0 );
+	  glMatrixMode(GL_MODELVIEW);
+	  glPushMatrix();//1
+	  glRotateL(minus*1.5,0,1,0);
+	  xray_eye=1;
+	  glScissor(vp[0],vp[1],vp[2]/2,vp[3]);
+	  glEnable(GL_SCISSOR_TEST);
+	  glDrawBuffer(GL_BACK_RIGHT);
+	  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	  if (!pause) draw();
+	  glPopMatrix();//1
+	  glPushMatrix();//1
+	  glRotateL(minus*1.5,0,1,0);
+	  xray_eye=2;
+	  glScissor(vp[0],vp[1],vp[2],vp[3]);
+	  glScissor(vp[2]/2,vp[1],vp[2],vp[3]);
+	  glEnable(GL_SCISSOR_TEST);
+	  glDrawBuffer(GL_BACK_RIGHT);
+	  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	  if (!pause) draw();
+	  xray_eye=0;
+	  glPopMatrix();//1
+	  glPopMatrix();//2
 
+	  glPushMatrix();//2
+	  glViewport(0, 0, ww, wh);        
+	  glMatrixMode(GL_PROJECTION);
+	  glLoadIdentity();
+	  gluPerspective( viewAngle, (double)ww/wh, 5.0, 8000.0 );
+	  glMatrixMode(GL_MODELVIEW);// */
+	  glPushMatrix();//1
+	  glRotateL(minus*-1.5,0,1,0);
+	  xray_eye=1;
+	  glScissor(vp[0],vp[1],vp[2]/2,vp[3]);
+	  glEnable(GL_SCISSOR_TEST);
+	  glDrawBuffer(GL_BACK_LEFT);
+	  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	  if (!pause) draw();
+	  glPopMatrix();//1
+	  glPushMatrix();//2
+	  glRotateL(minus*-1.5,0,1,0);
+	  xray_eye=2;
+	  glScissor(vp[0],vp[1],vp[2],vp[3]);
+	  glScissor(vp[2]/2,vp[1],vp[2],vp[3]);
+	  glEnable(GL_SCISSOR_TEST);
+	  glDrawBuffer(GL_BACK_LEFT);
+	  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	  if (!pause) draw();
+	  xray_eye=0;
+	  glPopMatrix();//1
+	  glPopMatrix();//2
+	}
+	else{
+	  glGetIntegerv(GL_VIEWPORT, vp);
+
+	  //  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	  glPushMatrix();//2
+	  glViewport(0, 0, ww, wh);        
+	  glMatrixMode(GL_PROJECTION);
+	  glLoadIdentity();
+	  gluPerspective( viewAngle, (double)ww/wh, 5.0, 8000.0 );
+	  glMatrixMode(GL_MODELVIEW);
+	  glPushMatrix();
+	  glRotateL(1.5*minus,0,1,0);
+	  xray_eye=0;
+	  glDrawBuffer(GL_BACK_RIGHT);
+	  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	  if (!pause) draw();
+	  glPopMatrix();
+	  glPopMatrix();
+
+	  glPushMatrix();
+	  glViewport(0, 0, ww, wh);        
+	  glMatrixMode(GL_PROJECTION);
+	  glLoadIdentity();
+	  gluPerspective( viewAngle, (double)ww/wh, 5.0, 8000.0 );
+	  glMatrixMode(GL_MODELVIEW);
+	  glPushMatrix();
+	  glRotateL(-1.5*minus,0,1,0);
+	  xray_eye=0;
+	  glDrawBuffer(GL_BACK_LEFT);
+	  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	  if (!pause) draw();
+	  glPopMatrix();
+	  glPopMatrix();
+	}
+      }
 }
 
 void chGL::setViewAngle(double ang){
   if ((ang>0.001)&&(ang<160.0)){
-    //  printf("View angle = %g degrees. %10.8f %f\n",ang,ang/viewAngle,viewAngle);
+     // printf("View angle = %g degrees. %10.8f %f\n",ang,ang/viewAngle,viewAngle);
     glScaled(ang/viewAngle,ang/viewAngle,ang/viewAngle);
     viewAngle=ang;
     homeXY();
@@ -1882,7 +2016,7 @@ void chGL::setViewAngle(double ang){
 }
 
 void chGL::rehide(){
-  //  printf("haa %d %d %g\n",hideReason,hiddenThings,qcutoff);
+//    printf("haa %d %d %g\n",hideReason,hiddenThings,qcutoff);
   if (!hiddenThings) return;
   if ((hideReason&HIDE_REASON_SELECT)&&(mol->selectedatoms.size())) {hideNonSelected(); return;}
   else if (hideReason&HIDE_REASON_SELECT) hideReason-=HIDE_REASON_SELECT;
@@ -2032,7 +2166,6 @@ void chGL::hideQPeaksBelow(double cutoff){
     if (mol->showatoms[i].an < 0) mol->showatoms[i].hidden = (mol->showatoms[i].peakHeight<cutoff)?1:0;
     if (mol->showatoms[i].an == -66) mol->showatoms[i].hidden = 0;
     nach += mol->showatoms[i].hidden;
-
   }
   if (vor==nach) return;
   hiddenThings=true;
@@ -2186,9 +2319,10 @@ void chGL::draw(){
   glLoadIdentity();
   glDisable(GL_CLIP_PLANE1);
   glDisable(GL_CLIP_PLANE2);
+  
   double 
-	  clip_plane1[]={1.0,0.0,-1.0,-190},
-	  clip_plane2[]={-1.0,0.0,-1.0,-190};
+	  clip_plane1[]={1.0,0.0,-1.0, xrdist},
+	  clip_plane2[]={-1.0,0.0,-1.0,xrdist};
   glClipPlane(GL_CLIP_PLANE1,clip_plane1);
   glClipPlane(GL_CLIP_PLANE2,clip_plane2);
   glDisable( GL_LIGHTING ); 
@@ -2303,12 +2437,21 @@ void chGL::draw(){
     if (lighting->isChecked())  glEnable(GL_LIGHTING); 
     else glDisable(GL_LIGHTING);
     glEnable(GL_BLEND);
-    if (foact->isChecked()) glCallList(foubas[2+3*Pers]);
+    if (foact->isChecked()) {
+      glCallList(foubas[2+4*Pers]);
+      if (neutrons) glCallList(foubas[3+4*Pers]);
+    }
     if (fofcact->isChecked()) {
-      glCallList(foubas[0+3*Pers]);
-      glCallList(foubas[1+3*Pers]);
+      glCallList(foubas[0+4*Pers]);
+      glCallList(foubas[1+4*Pers]);
     }
     glEnable(GL_LIGHTING);
+    //}
+//    if (fofcact->isChecked()) {
+//      glCallList(foubas[0+4*Pers]);
+//      glCallList(foubas[1+4*Pers]);
+//    }
+//    glEnable(GL_LIGHTING);
     glDisable(GL_BLEND);
     glEnable(GL_CULL_FACE);
     glPolygonMode(GL_FRONT_AND_BACK,GL_FILL);
@@ -2491,7 +2634,7 @@ void chGL::draw(){
       glScaled(L,L,L);{
 	for (int j=0;j<mol->showatoms.size();j++){
 	  if (mol->showatoms.at(j).hidden) continue;
-	  if ((mol->nopm1)&&(mol->showatoms.at(j).symmGroup)&&(mol->showatoms.at(j).part==-1)) continue;
+	  if ((mol->nopm1)&&(mol->showatoms.at(j).symmGroup)&&(mol->showatoms.at(j).part<-0)) continue;
 	  if (imFokus==j) qglColor(Qt::yellow); else {
 	    if (mol->showatoms.at(j).symmGroup) {
 	      if ((backGroundColor.saturation()>128)&&(fabs(backGroundColor.hue()-240)<30)) qglColor(Qt::lightGray);
@@ -2582,7 +2725,7 @@ void chGL::draw(){
 	pla2=(out[0]*clip_plane2[0]+out[1]*clip_plane2[1]+out[2]*clip_plane2[2]+out[3]*clip_plane2[3]);
 	if ((xray_eye)&&(pla1<0)&&(pla2<0))continue;
 
-	if ((mol->nopm1)&&(mol->showatoms.at(j).symmGroup)&&(mol->showatoms.at(j).part==-1)) continue;
+	if ((mol->nopm1)&&(mol->showatoms.at(j).symmGroup)&&(mol->showatoms.at(j).part<-0)) continue;
 	if (!posTo2D(mol->showatoms.at(j).pos,model,proj,viewport, &mol->showatoms[j].screenX, &mol->showatoms[j].screenY))
 	{mol->showatoms[j].screenX=-200; mol->showatoms[j].screenY=-200;}
       }
