@@ -37,15 +37,17 @@
 class chGL : public QGLWidget{
 Q_OBJECT
 public:
-    explicit chGL(QWidget *parent = 0);
+    explicit chGL(QWidget * parent = 0);
     int www,ww,wh,minus;
     int stereo_mode;
     int objCnt;
+    double xrdist;
     int ImeanThisAtom;
     double viewAngle,envirange;
     QColor labelColor,backGroundColor;
     bool pause,inRenameMode,noWaitLabel;
     bool hiddenThings;
+    bool neutrons;
     QFont myFont,nonAtomFont;
     QTimer *moving;
     GLdouble MM[16];
@@ -72,7 +74,7 @@ public:
     void setupTexture();    
     void updateBondActions();
     Molecule *mol;
-    int bas,murx,foubas[36],wirbas;
+    int bas,murx,foubas[37],wirbas;
     double L;
     QAction *foact, *fofcact;
     int rotze;
@@ -80,6 +82,8 @@ public:
     QToolButton *rCenter;
     V3 altemitte;
 signals:
+    void newContext();
+    void no_hw_st();
     void message(const QString &);
     void bigmessage(const QString &);
     void jumpit(int index);
@@ -106,6 +110,7 @@ public slots:
     void parallel();
     void crosseye();
     void anaglyphRedCyan();
+    void hardwareStereo();
     void nostereo();
     void hideNonSelected();
     void showHidden();
