@@ -134,6 +134,9 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
     if (block.isVisible() && bottom >= event->rect().top()) {
       QString number = QString::number(blockNumber + 1);
       bool iscurrent=(blockNumber==current);
+      if (blockNumber%2) painter.fillRect(0, top,
+                                      lineNumberArea->width(),
+                                      fontMetrics().height(),QColor("#dddddd"));
       if (iscurrent) painter.fillRect(0, top,
                                       lineNumberArea->width(),
                                       fontMetrics().height(),QColor("#242424"));
@@ -145,6 +148,11 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
 			fontMetrics().height(),QColor("#aa0000"));
 	iscurrent=true;
       }
+      if (comment.at(blockNumber)) {
+    painter.fillRect(5, top+2,
+			3,//lineNumberArea->width()
+            fontMetrics().height()-4,(iscurrent)?QColor("#99aaff"):QColor("#0000aa"));
+      }
       
       
       //printf("edidor Font: %s %d %d %d\n",f.family().toStdString().c_str(),f.pointSize(),fontMetrics().height(),fontMetrics().lineSpacing ());
@@ -169,6 +177,14 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
   event->accept();
 }
 
+void CodeEditor::lineNumberToggled(QMouseEvent *event){
+    QTextBlock block=firstVisibleBlock();
+    int top = (int) blockBoundingGeometry(block).translated(contentOffset()).top();
+    int bn=firstVisibleBlock().blockNumber();
+    int idx=(int)  (event->y()-top)/ ((int) blockBoundingRect(block).height()) + bn + 1;
+remark(idx-1);
+}
+
 void CodeEditor::updateAfix(){
  // printf("updateAfix\n");
   blocks=toPlainText().split('\n');
@@ -180,9 +196,13 @@ void CodeEditor::updateAfix(){
   parenthesis.clear();
   parenthesis2.clear();
   parenthesis3.clear();
+  comment.clear();
   int probe=0,aprobe=0,amn=0;
   bool gutso=false;
+  bool kommentar=false;
   for (int i=0; i<blocks.size();i++){
+    kommentar =  (blocks.at(i).contains(QRegExp("^REM",Qt::CaseInsensitive)));
+    comment.append(kommentar);
       if (blocks.at(i).contains(QRegExp("^AFIX\\s+0",Qt::CaseInsensitive))) {
           probe=0;
           amn=0;
@@ -241,6 +261,49 @@ void CodeEditor::updateAfix(){
   afixHighlightArea->update();
 }
 
+void CodeEditor::remark(int line){
+  if (isReadOnly ())return;
+  QString zeile=blocks.at(line).simplified();
+  bool cont= blocks.at(qMax(0,line-1)).contains(QRegExp("=\\s*$"));
+  if (zeile.contains(QRegExp("^REM",Qt::CaseInsensitive))) {
+    zeile=zeile.remove(0,4);
+    if (cont) zeile.prepend(' ');
+  }
+  else zeile.prepend("REM ");  
+  QTextCursor cu=textCursor ();
+  cu.movePosition(QTextCursor::Start);
+  cu.movePosition(QTextCursor::Down,QTextCursor::MoveAnchor,line);
+  cu.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor);
+  cu.movePosition(QTextCursor::EndOfLine,QTextCursor::KeepAnchor);
+  if (!cu.selectedText().isEmpty()) cu.deleteChar();
+  cu.insertText(zeile);
+  //qDebug()<<zeile;
+
+}
+
+void CodeEditor::toggleRemaks(){
+QTextCursor cu=textCursor();
+cu.beginEditBlock();
+int start=0,end=0,hilf=0;
+QTextBlock block = firstVisibleBlock();
+while (block.isValid()){
+    if (block.contains(cu.selectionStart())) start= block.blockNumber();
+    if (block.contains(cu.selectionEnd())) end= block.blockNumber();		
+    block = block.next();
+}
+hilf=start;
+start=qMin(start,end);
+end=qMax(hilf,end);
+if (end!=start) {
+cu.clearSelection();
+for (int i=start; i<=end; i++) remark(i);
+//qDebug()<<cu.selectedText()<<"\n"<<start<<end;
+}
+cu.endEditBlock();
+cu.clearSelection();
+if (!cu.isNull()) setTextCursor(cu);
+}
+
 void CodeEditor::afixHighlightAreaPaintEvent(QPaintEvent *event){
 //   printf("\nafixHighlightAreaPaintEvent\n");
   QPainter apainter(afixHighlightArea);
@@ -330,9 +393,9 @@ if (event->type() == QEvent::ToolTip) {
         //qDebug()<<v<<res<<m;
         // std::cout<< av <<"abs  v"<< v <<" m ="<< m << " var =" << var <<" res = "<<res<< std::endl ;
         //return res;
-        if ((m)>fv.size())
-          msg+=QString("<font color=\"red\"><h1>Error in line %2!<br>Free Variable %1 is not defined yet!</h1></font><hr>")
-          .arg(m).arg(lnr);
+        if ((m)>fv.size()){
+          if (m>1) msg+=QString("<font color=\"red\">Error in line %2!<br>Free Variable %1 is not defined yet!</font><hr>")
+          .arg(m).arg(lnr);}
         else
           msg+=QString("Line <b>%3</b>: Free Variable <b>%1</b> gives <b> %2</b> here.<hr>")
                .arg(m).arg(res).arg(lnr);
@@ -354,7 +417,7 @@ void  CodeEditor::contextMenuEvent(QContextMenuEvent *event) {
      QTextCursor cursor = cursorForPosition( event->pos());
      QTextBlock block=cursor.block();
      QString aname=block.text().section(" ",0,0);
-     QStringList bfl=shxToolTips.filter(aname);
+     QStringList bfl=shxToolTips.filter(QRegExp(QString("^%1").arg(aname)));
      if (bfl.isEmpty()){
         QString data=block.text().remove("=").trimmed();                                      // findInStructure
         a=menu->addAction(QString("locate %1 in structure").arg(aname) ,this,SLOT(searchInStructure()));
@@ -366,6 +429,8 @@ void  CodeEditor::contextMenuEvent(QContextMenuEvent *event) {
          a=menu->addAction(QString("select atoms in structure found in selected text"),
                          this, SLOT(selectInStructure()));
          a->setData(textCursor().selectedText());
+	 a=menu->addAction(QString("toggle remarks states of selected text"),
+			 this,SLOT(toggleRemaks()));
      }
      //...
      menu->exec(event->globalPos());
