@@ -79,6 +79,7 @@ public:
     QList<int> parenthesis;
     QList<int> parenthesis2;
     QList<bool> parenthesis3;
+    QList<bool> comment;
     QList<double> fv;
     int fvMinLine;
 signals:
@@ -102,6 +103,9 @@ public slots:
     void insertCompletion(const QString &completion);
     void searchInStructure();
     void selectInStructure();
+    void lineNumberToggled(QMouseEvent *event);
+    void remark(int line);
+    void toggleRemaks();
     void setgl(chGL *g){
       chgl=g;
     }
@@ -147,6 +151,9 @@ protected:
   void paintEvent(QPaintEvent *event) {
     codeEditor->lineNumberAreaPaintEvent(event);
   }
+  void mousePressEvent ( QMouseEvent * event ){
+    codeEditor->lineNumberToggled(event);
+  }
 
 private:
   CodeEditor *codeEditor;
