@@ -17,6 +17,11 @@
  **
  ****************************************************************************/
 #include "eacDlg.h"
+#if defined (Q_WS_MAC)
+#include <glu.h>
+#else
+#include <GL/glu.h>
+#endif
 #ifndef PROGRAM_NAME
 #define PROGRAM_NAME "shelXle"
 #endif
@@ -349,6 +354,11 @@ void EacDlg::colorDLG2(){
 		    .arg(bgcolor.darker(200).name())
 		    .arg(bgcolor.lighter(200).name())
 		    .arg((bgcolor.value()<90)?"#ffffff":"#000000"));
+  mol->einstellung->beginGroup("Bonds");
+  mol->einstellung->setValue("BondColor",mol->bondColor);
+  mol->einstellung->setValue("BondStyle",mol->bondColorStyle);
+  mol->einstellung->setValue("BondStrength",mol->bondStrength);
+  mol->einstellung->endGroup();
   }
   update();
 }
@@ -691,6 +701,14 @@ EacDlg::EacDlg(Molecule *externMole){
   eacProba->addItem("30 % Probability",30);
   eacProba->addItem("10 % Probability",10);
   eacProba->setCurrentIndex(2);
+  switch (mol->proba){
+	  case 10: eacProba->setCurrentIndex(4);break; 
+	  case 30: eacProba->setCurrentIndex(3);break; 
+	  case 50: eacProba->setCurrentIndex(2);break; 
+	  case 70: eacProba->setCurrentIndex(1);break; 
+	  case 90: eacProba->setCurrentIndex(0);break; 
+  }
+ // printf("zwei %d \n",mol->proba);
   connect(eacProba,SIGNAL(currentIndexChanged(int)),this,SLOT(probaChanged(int)));
   QCheckBox *singleC =new QCheckBox("uni colored bonds");
   singleC->setChecked(mol->bondColorStyle);
