@@ -622,6 +622,7 @@ void FourXle::inimap(){//for screenies
 #include <omp.h>
 
 void FourXle::gen_surface(bool neu,int imin,int imax){
+  if (!chgl->neutrons) imax=qMin(3,imax);
   if ((chgl->centerSelection->isChecked())&&(mole->selectedatoms.isEmpty())){
     V3 v;
     mole->kart2frac(chgl->altemitte,v);
@@ -684,6 +685,13 @@ tri=0;
 		    break;
 	    case 2:                   
                    if (neu) iso[0]=sigma[1]*1.2;
+		   //printf("blau %g %d\n",iso[0],neu);
+                    mtyp=0;
+		    break;
+	    case 3:                   
+                   if (neu) iso[0]=-sigma[1]*1.2;
+                    else iso[0]=-fabs(iso[0]);
+		   //printf("orange %g %d\n",iso[0],neu);
                     mtyp=0;
 		    break;
     }
@@ -729,13 +737,30 @@ tri=0;
     }
     int mper=(chgl->niceTrans->isChecked())?6:1;
     for (int pers=0;pers<mper;pers++){
-      if (!chgl->foubas[fac+pers*3]) chgl->foubas[fac+pers*3]=glGenLists(1);
-      glNewList(chgl->foubas[fac+pers*3], GL_COMPILE );
+      if (!chgl->foubas[fac+pers*4]) chgl->foubas[fac+pers*4]=glGenLists(1);
+      glNewList(chgl->foubas[fac+pers*4], GL_COMPILE );
       glLineWidth(linwidth);
 	switch (fac) {
-		case 0: glColor4d(0.0, 0.7, 0.0, lintrans);break;
-		case 1: glColor4d(0.8, 0.0, 0.0, lintrans);break;
-		case 2: glColor4d(0.0, 0.0, 1.0, lintrans);break;
+		case 0: 
+			dipc.setAlphaF(lintrans);
+			chgl->qglColor(dipc);
+//			glColor4d(0.0, 0.7, 0.0, lintrans);
+			break;
+		case 1: 
+			dimc.setAlphaF(lintrans);
+			chgl->qglColor(dimc);
+//			glColor4d(0.8, 0.0, 0.0, lintrans);
+			break;
+		case 2: 
+			fopc.setAlphaF(lintrans);
+			chgl->qglColor(fopc);
+//			glColor4d(0.0, 0.0, 1.0, lintrans);
+			break;
+		case 3: 
+			fomc.setAlphaF(lintrans);
+			chgl->qglColor(fomc);
+//			glColor4d(1.0, 0.65, 0.0, lintrans);
+			break;
 	}
 	glPushMatrix();
 	glScaled(chgl->L,chgl->L,chgl->L);
@@ -814,6 +839,8 @@ tri=0;
       glEndList();
     }
   }
+ iso[0]=fabs(iso[0]);
+
   QString info=QString("<b>Fo-Fc1 Map:</b><font color=green>%1 e&Aring;<sup>-3</sup></font>"
 		  "<font color=red> %2 e&Aring;<sup>-3</sup> (&sigma; = %7) </font><br><font color=grey> Hint:  [%3 Scroll (up or down)] to change. </font><br>"
                   "<b>Fo-Map:</b><font color=blue>%4  e&Aring;<sup>-3</sup> (&sigma; = %8)</font><br><font color=grey> Hint:  [%5 Scroll (up or down)] to change. </font><br>Time for creating map surfaces <b>%6 s</b>. %9 Triangles drawn.<br>")
@@ -839,6 +866,7 @@ tri=0;
 
 void FourXle::change_iso(int numsteps,int diff){
   disconnect(chgl,SIGNAL(diffscroll(int ,int )),0,0);
+  iso[diff]=fabs(iso[diff]);
   iso[diff]+=iso[diff]*numsteps/10.0;
   int mi=0,ma=5;
   balken->setMinimum(0);
@@ -847,7 +875,7 @@ void FourXle::change_iso(int numsteps,int diff){
   balkenstep=0;
   switch (diff) {
 	  case 0: 
-		  mi=2;ma=3;
+		  mi=2;ma=4;
 		  break;
 	  case 1:
 		  mi=0; ma=2;
