@@ -32,6 +32,7 @@
 #include "historywidget.h"
 #include "savehistorywidget.h"
 #include "fourxle.h"
+#include "fcvsfo.h"
 
 //struct Node {
 //  int index;
@@ -94,12 +95,17 @@ public:
 //  void changeWeight();
   void clipboardDataChanged();
   void closeEvent(QCloseEvent *event);
+  void colorDLGFOP();
+  void colorDLGFOM();
+  void colorDLGDIP();
+  void colorDLGDIM();
   void controlMap();
   void complete();
   void configureBottomToolbar();
   void copySymmMate();
   void createCentroid();
   void decreaseEdtiorFont();
+  void defaultColors();
   void deleteAllH();
   void deleteAllQ();
   void deleteSelectedAtoms();
@@ -121,6 +127,7 @@ public:
   void findResi(QString);
   void findText();
   void findText2();
+  void foversusfc();
   void fuse();
   void grossRC(const QString &text);
   void grow();
@@ -148,6 +155,7 @@ public:
   void mapDefault();
   void moveSymmMate();
   void moveSymmMateSel();
+  void omitsome(const QString &s);
   void openFile();
   void openMapControl();
   void openRecentFile();
@@ -177,6 +185,7 @@ public:
   void selectParts();
   void setShelxlPath();
   void setExtraPath();
+  void setMonoQ(bool vis);
   void showSearch();
   void showSearch2();
   void shxActUpdate(bool vis);
@@ -190,6 +199,7 @@ public:
   void symmetryManager();
   void toggDocWid(bool weg);
   void toggleOrtho(bool ov);
+  void trick();
   void undoRename();
   void uniq();
   void updateLabel();
@@ -278,6 +288,7 @@ private:
   QDockWidget *dock, *renamDock, *qPeakDock, *histDock;
   QComboBox *mapSchnitt;
   QDoubleSpinBox *maprad,*fomaps,*difmaps,*weak,*mapprec,*lineTrans,*lineWidth;
+  QPushButton *foPlusButton,*foMinusButton,*diffPlusButton,*diffMinusButton, *defColorButton;
   QDialog *md;
   QSpinBox *widthBox;       
   QSpinBox *heightBox;      
@@ -301,8 +312,9 @@ private:
   QLineEdit *extraPath,*extraName,*extraAltExtEdit,*extraArgumentsEdit;
   QDockWidget *helpDock;
   QWebView *hilfe;
+  //QTextBrowser *hilfe;
   QWidget *shx_group;
-  QVBoxLayout *sss;
+  QVBoxLayout *sss,*amdl;
   QHBoxLayout *nlt;
   QGroupBox *renameBox ;
   QVBoxLayout *rnla;    
@@ -310,8 +322,8 @@ private:
   QHBoxLayout *sfacla;
   QScrollArea *qsa,*qsa2;
   QMenu *fileMenu, *editMenu, *dialogMenu, *viewMenu, *runMenu, *packMenu, *extraMenu;         
-  QAction *zm_stereo, *pe_stereo, *xe_stereo, *an_stereo, *no_stereo; 
-
+  QAction *zm_stereo, *pe_stereo, *xe_stereo, *an_stereo, *hw_stereo, *no_stereo; 
+  QAction *fcvsfoAct;
 
 
 
@@ -320,7 +332,7 @@ private:
   QVBoxLayout *lt;
   QToolButton  *zoomIn,*zoomOut;
   QLabel *sLabel;
-  QCheckBox *qGrowPeak;
+  QCheckBox *qGrowPeak,*search4duplicates;
   QTimer *hidwillpse;
   QLabel *indexL,*sufixL;
   QLabel *scalwla, *scalhla, *scalsla, *header;
